@@ -1151,9 +1151,9 @@ def cleanupHTML(doc):
             el.set("data-noexport", "")
 
         if doc.md.slimBuildArtifact:
-            # Remove *all* data- attributes.
+            # Remove *all* data- attributes, except data-mdn-for attributes
             for attrName in el.attrib:
-                if attrName.startswith("data-"):
+                if attrName.startswith("data-") and attrName != "data-mdn-for":
                     removeAttr(el, attrName)
     for el in strayHeadEls:
         head.append(el)
@@ -1242,7 +1242,7 @@ def formatArgumentdefTables(doc):
                     appendChild(tds[3],
                                 E.span({"class":"no"}, "✘"))
             else:
-                die("Can't find the '{0}' argument of method '{1}' in the argumentdef block.", argName, method.fullName, el=table)
+                die(f"Can't find the '{argName}' argument of method '{method.full_name}' in the argumentdef block.", el=table)
                 continue
 
 
