@@ -10,6 +10,30 @@ from datetime import datetime
 
 from ..messages import *
 
+# Manifest creation relies on these data structures.
+# Add to them whenever new types of data files are created.
+knownFiles = [
+    "biblio-keys.json",
+    "biblio-numeric-suffixes.json",
+    "bikeshed-version.txt",
+    "fors.json",
+    "languages.json",
+    "link-defaults.infotree",
+    "mdn.json",
+    "methods.json",
+    "specs.json",
+    "test-suites.json",
+    "version.txt",
+    "wpt-tests.txt",
+]
+knownFolders = [
+    "anchors",
+    "biblio",
+    "caniuse",
+    "headings",
+    "mdn",
+]
+
 def createManifest(path, dryRun=False):
     '''Generates a manifest file for all the data files.'''
     manifests = []
@@ -34,25 +58,6 @@ def createManifest(path, dryRun=False):
         except Exception as err:
             raise
 
-
-knownFiles = [
-    "fors.json",
-    "specs.json",
-    "methods.json",
-    "wpt-tests.txt",
-    "languages.json",
-    "biblio-keys.json",
-    "test-suites.json",
-    "link-defaults.infotree",
-]
-knownFolders = [
-    "anchors",
-    "biblio",
-    "headings",
-    "caniuse"
-]
-
-
 def keyManifest(manifest):
     name = manifest[0]
     if "/" in name:
@@ -127,8 +132,8 @@ def updateByManifest(path, dryRun=False):
 
     if not dryRun:
         import time
-        messageDelta = .5 # seconds of *processor* time, not wall time :(
-        lastMsgTime = time.clock()
+        messageDelta = 2.5 # wall time
+        lastMsgTime = time.time()
         if newPaths:
             say("Updating {0} file{1}...", len(newPaths), "s" if len(newPaths) > 1 else "")
         for i,filePath in enumerate(newPaths):
@@ -150,7 +155,7 @@ def updateByManifest(path, dryRun=False):
                 warn("Couldn't save file '{0}'.\n{1}", localPath, e)
                 return False
 
-            currFileTime = time.clock()
+            currFileTime = time.time()
             if (currFileTime - lastMsgTime) >= messageDelta:
                 say("Updated {0}/{1}...", i+1, len(newPaths))
                 lastMsgTime = currFileTime
